@@ -2,7 +2,7 @@ use super::{
     comments_buffer::{BufferedComment, BufferedCommentKind},
     Context, Input, Lexer,
 };
-use crate::{error::Error, input::Tokens, lexer::util::CharExt, token::*, JscTarget, Syntax};
+use crate::{error::Error, input::Tokens, lexer::util::CharExt, token::*, EsVersion, Syntax};
 use enum_kind::Kind;
 use std::mem::take;
 use swc_common::BytePos;
@@ -124,7 +124,7 @@ impl<I: Input> Tokens for Lexer<'_, I> {
     fn syntax(&self) -> Syntax {
         self.syntax
     }
-    fn target(&self) -> JscTarget {
+    fn target(&self) -> EsVersion {
         self.target
     }
 
@@ -673,7 +673,7 @@ pub enum TokenContext {
 #[cfg(test)]
 pub(crate) fn with_lexer<F, Ret>(
     syntax: Syntax,
-    target: JscTarget,
+    target: EsVersion,
     s: &str,
     f: F,
 ) -> Result<Ret, ::testing::StdErr>
@@ -721,7 +721,7 @@ pub(crate) fn lex_tokens(syntax: Syntax, s: &'static str) -> Vec<Token> {
 #[cfg(test)]
 pub(crate) fn lex_tokens_with_target(
     syntax: Syntax,
-    target: JscTarget,
+    target: EsVersion,
     s: &'static str,
 ) -> Vec<Token> {
     with_lexer(syntax, target, s, |l| Ok(l.map(|ts| ts.token).collect())).unwrap()
@@ -731,7 +731,7 @@ pub(crate) fn lex_tokens_with_target(
 /// if the lexer fails to recover from it.
 #[cfg(test)]
 pub(crate) fn lex_errors(syntax: Syntax, s: &'static str) -> (Vec<Token>, Vec<Error>) {
-    with_lexer(syntax, JscTarget::Es2020, s, |l| {
+    with_lexer(syntax, EsVersion::Es2020, s, |l| {
         let tokens = l.map(|ts| ts.token).collect();
         let errors = l.take_errors();
         Ok((tokens, errors))
